Nick's Python Toolchest - 0.5.0
===============================

An etherogeneous collection of useful Python stuff. Contains the following packages:

* *ccase*:   A Python API to the ClearCase version control tool.
* *command*: Tools to wrap possibly interactive commands with complex option sets.
* *core*:    Various utilities, such as:

  * *backup_file*: Create backups for files you need to modify.
  * *file*:        File related utilities.
  * *memo*:        Base class for memoizable objects.
  * *past*:        Tools for Python version compatibility management.
  * *path*:        Filesystem related utilities.
  * *sequence*:    Sequence related utilities.
  * *sort*:        Sorting functions.
  * *temp_file*:   Temporary files and directories implemented as context managers.
  
* *etree*:   ElementTree related utilities.
* *maven*:   A Python interface to the Maven build tool.
* *msvs*:    A Python interface to Microsoft Visual Studio projects and the msbuild build tool.
* *ply*:     An object oriented wrapper for the PLY lexer/parser tool.
* *scons*:   Add-ons for the SCons build tool.
* *svn*:     A wrapper for the Subversion version control tool.
* *test*:    Testing related utilities.
* *wx*:      wxPython related utilities.
* *xml*:     XML related support classes, based on the lxml library.
